@@ -14,7 +14,7 @@ class MQTTClient():
         self.topics = []
 
     def publish(self, topic, msg):
-        self.client.publish(topic, base64.b64encode(zlib.compress(msg)))
+        self.client.publish(topic, bytes(zlib.compress(bytes(msg, 'utf-8'))))
 
     def subscribe(self, topic):
         if topic is not None:
