@@ -36,8 +36,8 @@ def get_type_index(type):
 
 def insert_type(new_type):
     sql = """
-        INSERT INTO Types (type) VALUES ("{}") WHERE NOT EXISTS ( SELECT * FROM Types WHERE type = "{}");
-        """.format(new_type, new_type)
+        INSERT OR IGNORE INTO Types (type) VALUES ("{}");
+        """.format(new_type)
     return sql
 
 def create_edge_table():
